@@ -37,10 +37,18 @@ def main():
   usage = """usage: %prog [options] [datafile1] [datafile2 ...]
   Ejemplo de uso:
 
-  %prog --search=LastName1:author --search=LastName2:author --search=LastName3:author --startyear=2000 --endyear=2008 --filter-exclude=2006:year --filter-exclude=LastName4:author --sort=year,month,author --format=tex --output=salida.tex biblio1.bib biblio2.bib.bz2 biblio1.dmp biblio2.dmp.gz
+  $> %prog --search=LastName1:author --search=LastName2:author --search=LastName3:author --startyear=2000 --endyear=2008 --filter-exclude=2006:year --filter-exclude=LastName4:author --sort=year,month,author --format=tex --output=salida.tex biblio1.bib biblio2.bib.bz2 biblio1.dmp biblio2.dmp.gz
 
 Will get data from two bibtex files (biblio1.bib and biblio2.bib.bz2) and two dump files (biblio1.dmp and biblio2.dmp.gz) and retain all entries between 2000 and 2008 (except those of 2006) by authors LastName1,LastName2 and LastName3 but where LastName4 is not an author. The search is case insensitive. The output is written in latex form, ordered by key in ascending order, to the file salida.tex
 
+  $> %prog - -o biblio.html
+Will get the data from standard input in BibTeX format and output it in html form to the file biblio.html
+
+                           ******** Working with pipes ********
+  $> %prog -s LastName1:author biblio1.bib -f bib -o - | %prog -s LastName2:author biblio2.dmp - -o biblio.html
+
+Will get the items with LastName1 as author from biblio1.bib and the results are taken as input to merge with items by LastName2 from database biblio2.dmp. The output is in html format to the file biblio.html
+
 Note that two of the input files are compressed
   """
   parser = optparse.OptionParser(usage)
@@ -116,18 +124,17 @@ Note that two of the input files are compressed
     if '.dmp' in fname:
       try:    b.load(fname)
       except: failed=True
-    elif '.bib' in fname:
+    elif '.bib' in fname or fname=='-':
       try: b.import_bibtex(fname, normalize=modify_keys)
       except: failed=True
     else: failed= True
+    if op.verbose:  print '# %d new items read' %(len(b.ListItems))
+
 
     if failed: 
-      mensaje= '''Database file %s not found or failed to load. Set the name as an option or set the environment variable BIBDB'''%(fname)
+      mensaje= 'Database file %s not found or failed to load. Set the name as an option or set the environment variable BIBDB\n'%(fname)
       parser.error(mensaje)
 
-  if op.verbose:
-    print '# %d new items read' %(len(b.ListItems))
-
   if op.sort != None:
     sortorder= op.sort.lower().split(',')
     if 'reverse' in sortorder:      reverse=True
